{% load i18n %}
<div class="failure sequence proctored-exam" data-exam-id="{{exam_id}}">
  <h3>
    {% blocktrans %}
      Error with proctored exam
    {% endblocktrans %}
  </h3>

  <p>
    {% blocktrans %}
      A technical error has occurred with your proctored exam. To resolve this problem, contact
      <a href="mailto:{{tech_support_email}}">technical support</a>. All exam data, including answers
      for completed problems, has been lost. When the problem is resolved you will need to restart
      the exam and complete all problems again.
    {% endblocktrans %}
  </p>
</div>
<div class="footer-sequence border-b-0 padding-b-0">
  <p>
    {% blocktrans %}
      If you have concerns about your proctoring session results, contact your course team.
    {% endblocktrans %}
  </p>
  <div class="clearfix"></div>
</div>
{% include 'proctored_exam/footer.html' %}
